@@ -26,28 +26,20 @@ extern "C" {
   Define declarations.
 */
 #define MagickPackageName "ImageMagick"
-#define MagickCopyright  "© 1999-2020 ImageMagick Studio LLC"
+#define MagickCopyright  "© 1999-2021 ImageMagick Studio LLC"
 #define MagickLibVersion  0x69B
 #define MagickLibVersionText  "6.9.11"
 #define MagickLibVersionNumber  6,0,0
-#define MagickLibAddendum  "-56"
+#define MagickLibAddendum  "-58"
 #define MagickLibInterface  6
 #define MagickLibMinInterface  6
-#if defined(_WINDOWS)
-#  if defined(_WIN64)
-#    define MagickPlatform "x64"
-#  else
-#    define MagickPlatform "x86"
-#  endif
-#else
 #define MagickPlatform  "aarch64"
-#endif
 #define MagickppLibVersionText  "6.9.11"
 #define MagickppLibVersionNumber  8:0:0
-#define MagickppLibAddendum  "-56"
+#define MagickppLibAddendum  "-58"
 #define MagickppLibInterface  8
 #define MagickppLibMinInterface  8
-#define MagickReleaseDate  "2021-01-08"
+#define MagickReleaseDate  "2021-01-16"
 #define MagickHomeURL  "file:///usr/share/doc/ImageMagick-6/index.html"
 #define MagickAuthoritativeLicense  \
   "https://imagemagick.org/script/license.php"
